@@ -2,7 +2,7 @@
 
 class API extends Handler {
 
-	const API_LEVEL  = 7;
+	const API_LEVEL  = 8;
 
 	const STATUS_OK  = 0;
 	const STATUS_ERR = 1;
@@ -202,6 +202,9 @@ class API extends Handler {
 
 			$override_order = false;
 			switch ($_REQUEST["order_by"]) {
+				case "title":
+					$override_order = "ttrss_entries.title";
+					break;
 				case "date_reverse":
 					$override_order = "score DESC, date_entered, updated";
 					break;
@@ -310,7 +313,7 @@ class API extends Handler {
 		if ($article_id) {
 
 			$query = "SELECT id,title,link,content,feed_id,comments,int_id,
-				marked,unread,published,score,
+				marked,unread,published,score,note,lang,
 				".SUBSTRING_FOR_DATE."(updated,1,16) as updated,
 				author,(SELECT title FROM ttrss_feeds WHERE id = feed_id) AS feed_title
 				FROM ttrss_entries,ttrss_user_entries
@@ -342,7 +345,9 @@ class API extends Handler {
 						"feed_id" => $line["feed_id"],
 						"attachments" => $attachments,
 						"score" => (int)$line["score"],
-						"feed_title" => $line["feed_title"]
+						"feed_title" => $line["feed_title"],
+						"note" => $line["note"],
+						"lang" => $line["lang"]
 					);
 
 					foreach (PluginHost::getInstance()->get_hooks(PluginHost::HOOK_RENDER_ARTICLE_API) as $p) {
@@ -423,7 +428,7 @@ class API extends Handler {
 
 			$checked = false;
 			foreach ($article_labels as $al) {
-				if ($al[0] == $line['id']) {
+				if (feed_to_label_id($al[0]) == $line['id']) {
 					$checked = true;
 					break;
 				}
@@ -447,7 +452,7 @@ class API extends Handler {
 		$assign = (bool) $this->dbh->escape_string($_REQUEST['assign']) == "true";
 
 		$label = $this->dbh->escape_string(label_find_caption(
-			$label_id, $_SESSION["uid"]));
+			feed_to_label_id($label_id), $_SESSION["uid"]));
 
 		$num_updated = 0;
 
@@ -638,7 +643,7 @@ class API extends Handler {
 			$headlines = array();
 
 			while ($line = db_fetch_assoc($result)) {
-				$line["content_preview"] = truncate_string(strip_tags($line["content_preview"]), 100);
+				$line["content_preview"] = truncate_string(strip_tags($line["content"]), 100);
 				foreach (PluginHost::getInstance()->get_hooks(PluginHost::HOOK_QUERY_HEADLINES) as $p) {
 					$line = $p->hook_query_headlines($line, 100, true);
 				}
@@ -700,6 +705,8 @@ class API extends Handler {
 				$headline_row["author"] = $line["author"];
 
 				$headline_row["score"] = (int)$line["score"];
+				$headline_row["note"] = $line["note"];
+				$headline_row["lang"] = $line["lang"];
 
 				foreach (PluginHost::getInstance()->get_hooks(PluginHost::HOOK_RENDER_ARTICLE_API) as $p) {
 					$headline_row = $p->hook_render_article_api(array("headline" => $headline_row));
