@@ -112,7 +112,7 @@ class FeedItem_RSS extends FeedItem_Common {
 			array_push($encs, $enc);
 		}
 
-		$enclosures = $this->xpath->query("media:content | media:group/media:content", $this->elem);
+		$enclosures = $this->xpath->query("media:content", $this->elem);
 
 		foreach ($enclosures as $enclosure) {
 			$enc = new FeedEnclosure();
@@ -127,6 +127,40 @@ class FeedItem_RSS extends FeedItem_Common {
 			array_push($encs, $enc);
 		}
 
+
+		$enclosures = $this->xpath->query("media:group", $this->elem);
+
+		foreach ($enclosures as $enclosure) {
+			$enc = new FeedEnclosure();
+
+			$content = $this->xpath->query("media:content", $enclosure)->item(0);
+
+			$enc->type = $content->getAttribute("type");
+			$enc->link = $content->getAttribute("url");
+			$enc->length = $content->getAttribute("length");
+
+			$desc = $this->xpath->query("media:description", $content)->item(0);
+			if ($desc) {
+				$enc->title = strip_tags($desc->nodeValue);
+			} else {
+				$desc = $this->xpath->query("media:description", $enclosure)->item(0);
+				if ($desc) $enc->title = strip_tags($desc->nodeValue);
+			}
+
+			array_push($encs, $enc);
+		}
+
+		$enclosures = $this->xpath->query("media:thumbnail", $this->elem);
+
+		foreach ($enclosures as $enclosure) {
+			$enc = new FeedEnclosure();
+
+			$enc->type = "image/generic";
+			$enc->link = $enclosure->getAttribute("url");
+
+			array_push($encs, $enc);
+		}
+
 		return $encs;
 	}
 
