@@ -1,10 +1,12 @@
 <?php
 class Plugin {
-	private $link;
+	private $dbh;
 	private $host;
 
+	const API_VERSION_COMPAT = 1;
+
 	function init($host) {
-		$this->link = $host->get_link();
+		$this->dbh = $host->get_dbh();
 		$this->host = $host;
 	}
 
@@ -20,5 +22,9 @@ class Plugin {
 	function get_prefs_js() {
 		return "";
 	}
+
+	function api_version() {
+		return Plugin::API_VERSION_COMPAT;
+	}
 }
 ?>
