@@ -572,8 +572,9 @@ class Pref_Feeds extends Handler_Protected {
 		$last_error = $this->dbh->fetch_result($result, 0, "last_error");
 
 		if ($last_error) {
-			print "&nbsp;<span title=\"".htmlspecialchars($last_error)."\"
-				class=\"feed_error\">(error)</span>";
+			print "&nbsp;<img src=\"images/error.png\" alt=\"(error)\"
+				style=\"vertical-align : middle\"
+				title=\"".htmlspecialchars($last_error)."\">";
 
 		}
 
@@ -792,31 +793,10 @@ class Pref_Feeds extends Handler_Protected {
 		print "<div class=\"dlgSec\">".__("Feed")."</div>";
 		print "<div class=\"dlgSecCont\">";
 
-		/* Title */
-
-		print "<input dojoType=\"dijit.form.ValidationTextBox\"
-			disabled=\"1\" style=\"font-size : 16px; width : 20em;\" required=\"1\"
-			name=\"title\" value=\"\">";
-
-		$this->batch_edit_cbox("title");
-
-		/* Feed URL */
-
-		print "<br/>";
-
-		print __('URL:') . " ";
-		print "<input dojoType=\"dijit.form.ValidationTextBox\" disabled=\"1\"
-			required=\"1\" regExp='^(http|https)://.*' style=\"width : 20em\"
-			name=\"feed_url\" value=\"\">";
-
-		$this->batch_edit_cbox("feed_url");
-
 		/* Category */
 
 		if (get_pref('ENABLE_FEED_CATS')) {
 
-			print "<br/>";
-
 			print __('Place in category:') . " ";
 
 			print_feed_cat_select("cat_id", false,
@@ -862,7 +842,7 @@ class Pref_Feeds extends Handler_Protected {
 
 		$this->batch_edit_cbox("auth_login");
 
-		print "<br/><input dojoType=\"dijit.form.TextBox\" type=\"password\" name=\"auth_pass\"
+		print "<hr/> <input dojoType=\"dijit.form.TextBox\" type=\"password\" name=\"auth_pass\"
 			placeHolder=\"".__("Password")."\" disabled=\"1\"
 			value=\"\">";
 
@@ -1492,15 +1472,6 @@ class Pref_Feeds extends Handler_Protected {
 
 		print "</p>";
 
-		print_warning(__("You can disable all articles shared by unique URLs here."));
-
-		print "<p>";
-
-		print "<button dojoType=\"dijit.form.Button\" onclick=\"return clearArticleAccessKeys()\">".
-			__('Unshare all articles')."</button> ";
-
-		print "</p>";
-
 		PluginHost::getInstance()->run_hooks(PluginHost::HOOK_PREFS_TAB_SECTION,
 			"hook_prefs_tab_section", "prefFeedsPublishedGenerated");
 
