@@ -32,7 +32,7 @@ class Af_GoComics extends Plugin {
 
 					foreach ($entries as $entry) {
 
-						if (preg_match("/(http:\/\/assets.amuniversal.com\/.*)/i", $entry->getAttribute("src"), $matches)) {
+						if (preg_match("/(http:\/\/assets.amuniversal.com\/.*width.*)/i", $entry->getAttribute("src"), $matches)) {
 
 							$entry->setAttribute("src", $matches[0]);
 							$basenode = $entry;
@@ -40,6 +40,19 @@ class Af_GoComics extends Plugin {
 						}
 					}
 
+                    if (!$basenode) {
+                        // fallback on the smaller version
+                        foreach ($entries as $entry) {
+
+                            if (preg_match("/(http:\/\/assets.amuniversal.com\/.*)/i", $entry->getAttribute("src"), $matches)) {
+
+                                $entry->setAttribute("src", $matches[0]);
+                                $basenode = $entry;
+                                break;
+                            }
+                        }
+                    }
+
 					if ($basenode) {
 						$article["content"] = $doc->saveXML($basenode);
 						$article["plugin_data"] = "gocomics,$owner_uid:" . $article["plugin_data"];
