@@ -84,7 +84,7 @@ create table ttrss_counters_cache (
 	value integer not null default 0,
 	updated datetime not null,
 	foreign key (owner_uid) references ttrss_users(id) ON DELETE CASCADE
-);
+) ENGINE=InnoDB DEFAULT CHARSET=UTF8;
 
 create index ttrss_counters_cache_feed_id_idx on ttrss_counters_cache(feed_id);
 create index ttrss_counters_cache_owner_uid_idx on ttrss_counters_cache(owner_uid);
@@ -96,7 +96,7 @@ create table ttrss_cat_counters_cache (
 	value integer not null default 0,
 	updated datetime not null,
 	foreign key (owner_uid) references ttrss_users(id) ON DELETE CASCADE
-);
+) ENGINE=InnoDB DEFAULT CHARSET=UTF8;
 
 create index ttrss_cat_counters_cache_owner_uid_idx on ttrss_cat_counters_cache(owner_uid);
 
@@ -163,6 +163,7 @@ create table ttrss_entries (id integer not null primary key auto_increment,
 	date_updated datetime not null,
 	num_comments integer not null default 0,
 	plugin_data longtext,
+	lang varchar(2),
 	comments varchar(250) not null default '',
 	author varchar(250) not null default '') ENGINE=InnoDB DEFAULT CHARSET=UTF8;
 
@@ -301,7 +302,7 @@ create table ttrss_tags (id integer primary key auto_increment,
 
 create table ttrss_version (schema_version int not null) ENGINE=InnoDB DEFAULT CHARSET=UTF8;
 
-insert into ttrss_version values (121);
+insert into ttrss_version values (123);
 
 create table ttrss_enclosures (id integer primary key auto_increment,
 	content_url text not null,
@@ -434,7 +435,7 @@ create table ttrss_feedbrowser_cache (
 	feed_url text not null,
 	site_url text not null,
 	title text not null,
-	subscribers integer not null) DEFAULT CHARSET=UTF8;
+	subscribers integer not null) ENGINE=InnoDB DEFAULT CHARSET=UTF8;
 
 create table ttrss_labels2 (id integer not null primary key auto_increment,
 	owner_uid integer not null,
